"""
__author__ = '霍格沃兹测试开发学社'
__desc__ = '更多测试开发技术探讨，请访问：https://ceshiren.com/t/topic/15860'
"""
import allure
import jsonpath
import pytest
import requests

from utils.log_utils import logger

@allure.feature("宠物商店宠物搜索接口")
class TestPetstoreSearch:
    '''
    测试 petstore 查询宠物接口
    '''

    def setup_class(self):
        '''
        类级别的初始化操作
        在本测试类执行之前调用一次
        '''
        self.search_url = "https://petstore.swagger.io/v2/pet/findByStatus"


    @allure.story("调试接口用例")
    @allure.title("宠物查询接口冒烟用例")
    def test_search_pet(self):
        '''
        完成查询宠物接口的冒烟测试用例
        :return:
        '''
        # 发出接口请求所需要的数据
        # search_url = "https://petstore.swagger.io/v2/pet/findByStatus"
        params = {
            "status": "available"
        }
        with allure.step("发出宠物查询请求"):
            # 发出宠物查询请求
            r = requests.request("GET", self.search_url, params=params)
            logger.info(f"接口响应为 =====> {r.text}")
        with allure.step("断言接口请求是否成功"):
            # 断言接口请求是否成功
            assert r.status_code == 200
        with allure.step("业务断言"):
            # 业务断言
            # 断言响应返回的不是空列表
            assert r.json() != []
            # 断言响应体中返回的宠物都是搜索中对应的状态
            status_list = jsonpath.jsonpath(r.json(), "$..status")
            logger.info(f"获取到 status 列表为 ====> {status_list}")
            for s in status_list:
                assert s == "available"

    @pytest.mark.parametrize(
        "status",
        ["available", "pending", "sold"],
        ids=["available_pets", "pending_pets", "sold_pets"]
    )
    @allure.story("参数化实现宠物搜索接口冒烟用例")
    def test_search_pet_by_params(self, status):
        '''
        用参数化的形式完成查询宠物接口的冒烟测试用例
        :return:
        '''
        # 发出接口请求所需要的数据
        # search_url = "https://petstore.swagger.io/v2/pet/findByStatus"
        params = {
            "status": status
        }
        # 发出宠物查询请求
        r = requests.request("GET", self.search_url, params=params)
        logger.info(f"接口响应为 =====> {r.text}")
        # 断言接口请求是否成功
        assert r.status_code == 200
        # 业务断言
        # 断言响应返回的不是空列表
        assert r.json() != []
        # 断言响应体中返回的宠物都是搜索中对应的状态
        status_list = jsonpath.jsonpath(r.json(), "$..status")
        logger.info(f"获取到 status 列表为 ====> {status_list}")
        for s in status_list:
            assert s == status

    @pytest.mark.parametrize(
        "status",
        ["petstatus", 123456, ""],
        ids=["wrong_value", "number", "none_str"]
    )
    @allure.story("status 传入错误的值")
    def test_search_pet_failure(self, status):
        '''
        失败场景的用例
        :return:
        '''
        params = {
            "status": status
        }
        # 发出宠物查询请求
        r = requests.request("GET", self.search_url, params=params)
        logger.info(f"接口响应为 =====> {r.text}")
        # 断言接口请求是否成功
        assert r.status_code == 200
        # 业务断言
        # 断言响应返回的是空列表
        assert r.json() == []

    @allure.story("不传 status 参数")
    def test_search_pet_none_params(self):
        '''
        不传递 status 参数
        :return:
        '''
        # 发出宠物查询请求
        r = requests.request("GET", self.search_url)
        logger.info(f"接口响应为 =====> {r.text}")
        # 断言接口请求是否成功
        assert r.status_code == 200
        # 业务断言
        # 断言响应返回的是空列表
        assert r.json() == []

    @allure.story("传入非 status 参数")
    def test_search_pet_wrong_param(self):
        '''
        传递一个给 status 的参数
        '''
        params = {
            "key": "available"
        }
        # 发出宠物查询请求
        r = requests.request("GET", self.search_url, params=params)
        logger.info(f"接口响应为 =====> {r.text}")
        # 断言接口请求是否成功
        assert r.status_code == 200
        # 业务断言
        # 断言响应返回的是空列表
        assert r.json() == []