"""
__author__ = '霍格沃兹测试开发学社'
__desc__ = '更多测试开发技术探讨，请访问：https://ceshiren.com/t/topic/15860'
"""
import requests

get_url = "https://httpbin.ceshiren.com/get"
post_url = "https://httpbin.ceshiren.com/post"

def test_get():
    '''
    发出一个 get 请求
    :return:
    '''
    r = requests.get(get_url)
    print(f"get 接口响应为 {r}")

def test_post():
    '''
    发出一个 post 请求
    :return:
    '''

    r = requests.post(post_url)
    print(f"post 接口响应为 {r}")

def test_put():
    '''
    发出一个 put 请求
    :return:
    '''
    put_url = "https://httpbin.ceshiren.com/put"
    r = requests.put(put_url)
    print(f"put 接口响应为 {r}")

def test_delete():
    '''
    发出一个 delete 请求
    :return:
    '''
    delete_url = "https://httpbin.ceshiren.com/delete"
    r = requests.delete(delete_url)
    print(f"delete 接口响应为 {r}")

def test_request_get():
    '''
    通过 request 方法发出 get 请求
    :return:
    '''
    r = requests.request("get", get_url)
    print(f"使用 request 方法发出 get 请求，响应为 {r}")

def test_response():
    '''
    获取到的响应
    :return:
    '''
    r = requests.request("get", get_url)
    # 响应状态码
    print(r.status_code)
    # 获取响应头信息
    print(r.headers)
    # 获取响应体
    # 获取字符串格式的响应体，自动解码来自服务器的内容，以对应的格式进行展示
    print(r.text)
    # 获取字节流格式的响应体
    print(r.content)
    # 访问原始格式的响应，返回响应存储的内存地址
    print(r.raw)
    # 如果响应为 json 格式，可以直接转为 python 对象
    print(r.json())
    print(type(r.json()))

def test_params():
    '''
    发出一个携带请求参数（拼接在 url 中）的 get 请求
    :return:
    '''
    # 定义请求参数，用字典格式
    datas = {
        "key1": "value1",
        "key2": "value2"
    }
    r = requests.request("get", get_url, params=datas)
    print(r.text)

def test_headers():
    headers = {
        "user-agent": "feier"
    }
    r = requests.request("get", get_url, headers=headers)
    print(r.text)

def test_post_form():
    '''
    发送携带表单格式请求体的 post 请求
    :return:
    '''
    datas = {
        "form_key1": "form_value1",
        "form_key2": "form_value2"
    }
    r = requests.request("post", post_url, data=datas)
    print(r.text)

def test_post_json():
    '''
    发送携带 json 格式请求体的 post 请求
    :return:
    '''
    datas = {
        "json_key1": "json_value1",
        "json_key2": "json_value2"
    }
    r = requests.request("post", post_url, json=datas)
    print(r.text)

def test_post_file():
    '''
    发送上传文件的 post 请求
    :return:
    '''
    filename = "./file/file.txt"
    files = {
        "file": open(filename, 'rb')
    }
    r = requests.request("post", post_url, files=files)
    print(r.text)

def test_set_cookie():
    '''
    发送携带 cookie 设置的 get 请求
    :return:
    '''
    url = "https://httpbin.ceshiren.com/cookies/set"
    cookies = {
        "my_cookie": "hogwarts"
    }
    r = requests.request("get", url, cookies=cookies)
    print(r.text)
    # 断言接口状态
    assert r.status_code == 200
    # 断言业务是否符合预期
    assert r.json().get("cookies").get("my_cookie") == "hogwarts"
